=========
Idle-Rich
=========

This just literally bootloads IDLE with Rich in it.
I'm so creative.

WARNING: This package is *extremely* hacky. Do not use it for any sort of stable use.
-------------------------------------------------------------------------------------

If you still want to, :code:`pip install` and run :code:`idlerich` in console.